@@ -13,6 +13,7 @@ import netjfwatcher.common.view.MenuPreference;
 import netjfwatcher.engine.model.action.preference.PluginEditorIDPreference;
 import netjfwatcher.engine.socket.info.NodeInformation;
 import netjfwatcher.engine.view.editorpart.common.EditorInputNodeView;
+import netjfwatcher.socketclient.NetworkClientNodeTreeView;
 
 import org.eclipse.jface.action.Action;
 import org.eclipse.jface.action.IAction;
@@ -145,7 +146,8 @@ public class ActionBuilderNetworkCamera extends Action {
 					+ nodeInfo.getIpaddress() + ")";
 			try {
 				activePage.openEditor(new EditorInputNodeView(nodeName
-						+ " Camera Config", nodeInfo,
+						+ " Camera Config" + NetworkClientNodeTreeView
+                        .getTitleSuffixEngineAddress(), nodeInfo,
 						true), PluginEditorIDPreference.PLUGIN_CAMERA_CONFIG_EDITOR_VIEW_ID);
 
 				activePage.openEditor(
